#include <stdio.h>
#include <string.h>

#include "test_file_accessor.h"

TestFileAccessor::TestFileAccessor(fileid_t fileid, offset_t size)
: Accessor(fileid, size)
{
}

/* Data transfer helper methods. */

void TestFileAccessor::fill_populated(Flexpage *flexpage)
{
    Region *region = flexpage->region;
    offset_t filepos = flexpage->base_offset;

    /* Tag the region with file state. */

    region->fill(fileid, filepos);

    /* Write some data to each page of the flexpage in each region. This
       allows each page to be tested regardless of how large each flexpage
       or region is. */

    offset_t addr = flexpage->base_addr;
    offset_t limit = addr + flexpage->size;

    while (addr < limit)
    {
        /* Overwrite enough of any previous data to make the new data
           readable. */

        char tag[32];

        sprintf(tag, "%ld:%ld", fileid, filepos);

        memset((void *) addr, 0, strlen(tag) + 1);
        strcpy((char *) addr, tag);

        filepos += PAGE_SIZE;
        addr += PAGE_SIZE;
    }
}

void TestFileAccessor::flush_populated(Flexpage *flexpage)
{
    flexpage->region->flush();
}

// vim: tabstop=4 expandtab shiftwidth=4
